from beastiary.db.base_class import Base  # noqa
from beastiary.models.trace import Trace  # noqa
